==> deepin-screen-recorder_2.7.3.orig.tar.xz: deepin-screen-recorder-2.7.3/translations/deepin-screen-recorder_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="73"/>
        <source>Click tray icon 
or press the shortcut again to stop recording</source>
        <translation>Haz clic en el icono de la bandeja o pulsar de nuevo
el atajo de teclado para detener la grabación.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="67"/>
        <source>Deepin screen recorder</source>
        <translation>Videograbadora Deepin</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="118"/>
        <source>Start recording</source>
        <translation>Empezar a grabar</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="387"/>
        <source>Select area</source>
        <translation>Seleccionar área</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="137"/>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="185"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="195"/>
        <source>Record finished</source>
        <translation>Grabación terminada</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="196"/>
        <source>Saved to</source>
        <translation>Guardado en</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="45"/>
        <source>Click or drag to
select the area to record</source>
        <translation>Hacer clic o arrastrar para
seleccionar la zona que grabar.</translation>
    </message>
</context>
<context>
    <name>WindowManager</name>
    <message>
        <location filename="../src/window_manager.cpp" line="150"/>
        <location filename="../src/window_manager.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_2.8.0.orig.tar.xz: deepin-screen-recorder-2.8.0/translations/deepin-screen-recorder_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="78"/>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="76"/>
        <source>Deepin screen recorder</source>
        <translation>Videograbadora Deepin</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="136"/>
        <source>Start recording</source>
        <translation>Empezar a grabar</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="454"/>
        <source>Select area</source>
        <translation>Seleccionar área</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="229"/>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="291"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="301"/>
        <source>Recording finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="302"/>
        <source>Saved to</source>
        <translation>Guardado en</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="48"/>
        <source>Click or drag to
select the area to record</source>
        <translation>Hacer clic o arrastrar para
seleccionar la zona que grabar.</translation>
    </message>
</context>
</TS>
